@@ -16,7 +16,7 @@ for each in data:
     stkList[each["f12"]]['per'] = each['f9']
     stkList[each["f12"]]['mktCap'] = each['f20']
     stkList[each["f12"]]['flowCap'] = each['f21']
-    
+    stkList[each["f12"]]['market'] = each['f13']    
 
 def getStkName(code):
     return stkList[code]["name"]
@@ -28,4 +28,6 @@ def getMktCap(code):
     return stkList[code]["mktCap"]
 def getFlowCap(code):
     return stkList[code]["flowCap"]
+def getMarketId(code):
+    return stkList[code]['market']
 
